package com.jeeplus.test.wdt.merchantCompany.service;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jeeplus.common.redis.RedisUtils;
import com.jeeplus.sys.constant.CacheNames;
import com.jeeplus.sys.domain.DictValue;
import com.jeeplus.sys.service.DictTypeService;
import com.jeeplus.sys.service.dto.DictValueDTO;
import com.jeeplus.sys.service.mapstruct.DictValueWrapper;
import com.jeeplus.sys.utils.DictUtils;
import com.jeeplus.test.wdt.merchantCompany.domain.MerchantDetails;
import com.jeeplus.test.wdt.merchantCompany.mapper.MerchantDetailsMapper;
import com.jeeplus.test.wdt.merchantCompany.service.dto.MerchantDetailsDTO;
import com.jeeplus.test.wdt.merchantCompany.service.mapstuct.MerchantDetailsWrapper;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 入驻详情service
 * @author: 徐滕
 * @version: 2024-01-04 10:56
 */
@Service
@Transactional
public class MerchantDetailsService extends ServiceImpl<MerchantDetailsMapper, MerchantDetails> {

    @Autowired
    private MerchantDetailsWrapper merchantDetailsWrapper;

    @Autowired
    private DictValueWrapper dictValueWrapper;

    @Autowired
    private DictTypeService dictTypeService;


    /**
     * 查询详情
     * @return
     */
    public MerchantDetailsDTO getLimit1() {
        MerchantDetailsDTO limit1 = baseMapper.getLimit1();
        //查询字典中数据获取方式并修改
        List<DictValueDTO> merchantDataSourcesList = DictUtils.getDictDTOList("merchant_data_sources");
        if(merchantDataSourcesList.size()>0){
            for (DictValueDTO dictValueDTO : merchantDataSourcesList) {
                if("result".equals(dictValueDTO.getLabel())){
                    if(null != limit1){
                        limit1.setDataSourcesType(dictValueDTO.getValue());
                    }
                }
            }
        }
        return limit1;
    }


    /**
     * 保存或者更新详情信息
     *
     * @param merchantDetailsDTO
     */
    public void saveOrUpdate(MerchantDetailsDTO merchantDetailsDTO) {
        MerchantDetails merchantDetails = merchantDetailsWrapper.toEntity ( merchantDetailsDTO );
        super.saveOrUpdate ( merchantDetails );
    }

    /**
     * 保存或者更新详情信息
     *
     * @param dataSources
     */
    public void saveDataSources(String dataSources) {

        Integer redisLoginNumber = (Integer) RedisUtils.getInstance ().get ( CacheNames.MERCHANTDETAILS );

        //查询字典中数据获取方式并修改
        List<DictValueDTO> merchantDataSourcesList = DictUtils.getDictDTOList("merchant_data_sources");
        if(merchantDataSourcesList.size()>0){
            for (DictValueDTO dictValueDTO : merchantDataSourcesList) {
                if("result".equals(dictValueDTO.getLabel())){
                    dictValueDTO.setValue(dataSources);
                    DictValue dictValue = dictValueWrapper.toEntity ( dictValueDTO );
                    dictTypeService.saveDictValue(dictValue);
                }
            }
        }
    }

}
